searchData={"items":[{"type":"module","doc":"Elixir library for `https://www.forexfactory.com` API.","title":"ForexFactory","ref":"ForexFactory.html"},{"type":"function","doc":"","title":"ForexFactory.currencies/0","ref":"ForexFactory.html#currencies/0"},{"type":"function","doc":"Return data series for a given `event` or error if something goes wrong.\n\n    iex> ForexFactory.Events.Inflation.CPI |> ForexFactory.event!(:USD) |> ForexFactory.data(limit: 1)\n    {:ok,\n     %{\n       \"data\" => %{\n         \"events\" => [\n           %{\n             \"actual\" => 3.2,\n             \"actual_formatted\" => \"3.2%\",\n             \"date\" => \"Mar 12, 2024\",\n             \"dateline\" => 1710246600,\n             \"forecast\" => 3.1,\n             \"forecast_formatted\" => \"3.1%\",\n             \"id\" => 136044,\n             \"is_active\" => false,\n             \"is_most_recent\" => true,\n             \"revision\" => nil,\n             \"revision_formatted\" => nil\n           }\n         ],\n         \"future_timestamps\" => [1712005200],\n         \"past_timestamps\" => [1707831000]\n       },\n       \"meta\" => %{\n         \"decimals\" => 1,\n         \"ebase_event_id\" => 884,\n         \"interval_name\" => \"MN1\",\n         \"is_more\" => true,\n         \"zero_line\" => 0\n       }\n    }}\n\n    iex>  nil |> ForexFactory.data(limit: 1)\n    {:error, \"nil event\"}","title":"ForexFactory.data/2","ref":"ForexFactory.html#data/2"},{"type":"function","doc":"Return a specific event for given `type` and `currency` or error if not found.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event(:USD)\n    {:ok,\n      %ForexFactory.Event{\n      id: \"136038\",\n      type: ForexFactory.Events.Inflation.CoreCPI,\n      currency: :USD,\n      frequency: :MoM\n      }}\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event(:NZD)\n    {:error,\n      \"missing 'NZD' event of type Elixir.ForexFactory.Events.Inflation.CoreCPI\"}","title":"ForexFactory.event/2","ref":"ForexFactory.html#event/2"},{"type":"function","doc":"Return a specific event for given `type` and `currency` or raise error if not found.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event!(:USD)\n    %ForexFactory.Event{\n      id: \"136038\",\n      type: ForexFactory.Events.Inflation.CoreCPI,\n      currency: :USD,\n      frequency: :MoM\n    }\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.event!(:NZD)\n    ** (ArgumentError) missing 'NZD' event of type Elixir.ForexFactory.Events.Inflation.CoreCPI","title":"ForexFactory.event!/2","ref":"ForexFactory.html#event!/2"},{"type":"function","doc":"Return all events for a given `type`.\n\n    iex> ForexFactory.Events.Inflation.CoreCPI |> ForexFactory.events()\n    [\n      %ForexFactory.Event{\n        id: \"136038\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :USD,\n        frequency: :MoM\n      },\n      %ForexFactory.Event{\n        id: \"139672\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :JPY,\n        frequency: :YoY\n      },\n      %ForexFactory.Event{\n        id: \"138961\",\n        type: ForexFactory.Events.Inflation.CoreCPI,\n        currency: :EUR,\n        frequency: :YoY\n      }\n    ]","title":"ForexFactory.events/1","ref":"ForexFactory.html#events/1"},{"type":"type","doc":"","title":"ForexFactory.currency/0","ref":"ForexFactory.html#t:currency/0"},{"type":"type","doc":"","title":"ForexFactory.event/0","ref":"ForexFactory.html#t:event/0"},{"type":"type","doc":"","title":"ForexFactory.opts/0","ref":"ForexFactory.html#t:opts/0"},{"type":"type","doc":"","title":"ForexFactory.type/0","ref":"ForexFactory.html#t:type/0"},{"type":"module","doc":"Client for ForexFactory API","title":"ForexFactory.Client","ref":"ForexFactory.Client.html"},{"type":"function","doc":"","title":"ForexFactory.Client.data/2","ref":"ForexFactory.Client.html#data/2"},{"type":"module","doc":"A specific event with id, type and currency","title":"ForexFactory.Event","ref":"ForexFactory.Event.html"},{"type":"type","doc":"","title":"ForexFactory.Event.frequency/0","ref":"ForexFactory.Event.html#t:frequency/0"},{"type":"type","doc":"","title":"ForexFactory.Event.t/0","ref":"ForexFactory.Event.html#t:t/0"},{"type":"module","doc":"Business surveys events","title":"ForexFactory.Events.BusinessSurveys","ref":"ForexFactory.Events.BusinessSurveys.html"},{"type":"module","doc":"Business manufacturing surveys","title":"ForexFactory.Events.BusinessSurveys.Manufacturing","ref":"ForexFactory.Events.BusinessSurveys.Manufacturing.html"},{"type":"module","doc":"Business services surveys","title":"ForexFactory.Events.BusinessSurveys.Services","ref":"ForexFactory.Events.BusinessSurveys.Services.html"},{"type":"module","doc":"Events from Central Banks","title":"ForexFactory.Events.CentralBank","ref":"ForexFactory.Events.CentralBank.html"},{"type":"module","doc":"Interest Rate","title":"ForexFactory.Events.CentralBank.Rate","ref":"ForexFactory.Events.CentralBank.Rate.html"},{"type":"module","doc":"Consumer surveys events","title":"ForexFactory.Events.ConsumerSurveys","ref":"ForexFactory.Events.ConsumerSurveys.html"},{"type":"module","doc":"Consumer sentiment","title":"ForexFactory.Events.ConsumerSurveys.ConsumerSentiment","ref":"ForexFactory.Events.ConsumerSurveys.ConsumerSentiment.html"},{"type":"module","doc":"Inflation expectations","title":"ForexFactory.Events.ConsumerSurveys.InflationExpectations","ref":"ForexFactory.Events.ConsumerSurveys.InflationExpectations.html"},{"type":"module","doc":"Labour events","title":"ForexFactory.Events.Employment","ref":"ForexFactory.Events.Employment.html"},{"type":"module","doc":"Change in the number of employed people during the previous period","title":"ForexFactory.Events.Employment.EmploymentChange","ref":"ForexFactory.Events.Employment.EmploymentChange.html"},{"type":"module","doc":"Change in the number of job cuts announced by employers","title":"ForexFactory.Events.Employment.JobCuts","ref":"ForexFactory.Events.Employment.JobCuts.html"},{"type":"module","doc":"Number of job openings during the reported period","title":"ForexFactory.Events.Employment.JobOpenings","ref":"ForexFactory.Events.Employment.JobOpenings.html"},{"type":"module","doc":"The number of individuals who filed for unemployment insurance","title":"ForexFactory.Events.Employment.JoblessClaims","ref":"ForexFactory.Events.Employment.JoblessClaims.html"},{"type":"module","doc":"Percentage of the total work force that is unemployed and actively seeking employment during the previous","title":"ForexFactory.Events.Employment.UnemploymentRate","ref":"ForexFactory.Events.Employment.UnemploymentRate.html"},{"type":"module","doc":"Economy growth events","title":"ForexFactory.Events.Growth","ref":"ForexFactory.Events.Growth.html"},{"type":"module","doc":"Core retail sales","title":"ForexFactory.Events.Growth.CoreRetailSales","ref":"ForexFactory.Events.Growth.CoreRetailSales.html"},{"type":"module","doc":"Gross Domestic Product","title":"ForexFactory.Events.Growth.GDP","ref":"ForexFactory.Events.Growth.GDP.html"},{"type":"module","doc":"Retail sales","title":"ForexFactory.Events.Growth.RetailSales","ref":"ForexFactory.Events.Growth.RetailSales.html"},{"type":"module","doc":"Housing events","title":"ForexFactory.Events.Housing","ref":"ForexFactory.Events.Housing.html"},{"type":"module","doc":"Building permits events","title":"ForexFactory.Events.Housing.BuildingPermits","ref":"ForexFactory.Events.Housing.BuildingPermits.html"},{"type":"module","doc":"Construction spending events","title":"ForexFactory.Events.Housing.ConstructionSpending","ref":"ForexFactory.Events.Housing.ConstructionSpending.html"},{"type":"module","doc":"Existing home sales events","title":"ForexFactory.Events.Housing.ExistingHomeSales","ref":"ForexFactory.Events.Housing.ExistingHomeSales.html"},{"type":"module","doc":"House prices index events","title":"ForexFactory.Events.Housing.HPI","ref":"ForexFactory.Events.Housing.HPI.html"},{"type":"module","doc":"Pending home sales events","title":"ForexFactory.Events.Housing.HousingStarts","ref":"ForexFactory.Events.Housing.HousingStarts.html"},{"type":"module","doc":"New home sales events","title":"ForexFactory.Events.Housing.NewHomeSales","ref":"ForexFactory.Events.Housing.NewHomeSales.html"},{"type":"module","doc":"Pending home sales events","title":"ForexFactory.Events.Housing.PendingHomeSales","ref":"ForexFactory.Events.Housing.PendingHomeSales.html"},{"type":"module","doc":"Inflation events","title":"ForexFactory.Events.Inflation","ref":"ForexFactory.Events.Inflation.html"},{"type":"module","doc":"Consumer Price Index","title":"ForexFactory.Events.Inflation.CPI","ref":"ForexFactory.Events.Inflation.CPI.html"},{"type":"module","doc":"Core Consumer Price Index","title":"ForexFactory.Events.Inflation.CoreCPI","ref":"ForexFactory.Events.Inflation.CoreCPI.html"},{"type":"module","doc":"Average Earnings","title":"ForexFactory.Events.Inflation.Earnings","ref":"ForexFactory.Events.Inflation.Earnings.html"},{"type":"behaviour","doc":"Behaviour for all event types","title":"ForexFactory.Events.Type","ref":"ForexFactory.Events.Type.html"},{"type":"callback","doc":"","title":"ForexFactory.Events.Type.all/0","ref":"ForexFactory.Events.Type.html#c:all/0"},{"type":"callback","doc":"","title":"ForexFactory.Events.Type.data/2","ref":"ForexFactory.Events.Type.html#c:data/2"},{"type":"callback","doc":"","title":"ForexFactory.Events.Type.data!/2","ref":"ForexFactory.Events.Type.html#c:data!/2"},{"type":"macro","doc":"","title":"ForexFactory.Events.Type.defevent/1","ref":"ForexFactory.Events.Type.html#defevent/1"},{"type":"callback","doc":"","title":"ForexFactory.Events.Type.event/1","ref":"ForexFactory.Events.Type.html#c:event/1"},{"type":"callback","doc":"","title":"ForexFactory.Events.Type.event!/1","ref":"ForexFactory.Events.Type.html#c:event!/1"},{"type":"type","doc":"","title":"ForexFactory.Events.Type.currency/0","ref":"ForexFactory.Events.Type.html#t:currency/0"},{"type":"type","doc":"","title":"ForexFactory.Events.Type.t/0","ref":"ForexFactory.Events.Type.html#t:t/0"},{"type":"module","doc":"HTTP Client","title":"ForexFactory.HttpClient","ref":"ForexFactory.HttpClient.html"},{"type":"function","doc":"","title":"ForexFactory.HttpClient.api_url/0","ref":"ForexFactory.HttpClient.html#api_url/0"},{"type":"function","doc":"","title":"ForexFactory.HttpClient.get/2","ref":"ForexFactory.HttpClient.html#get/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}